@@ -6,6 +6,7 @@ import grp
 import locale
 import subprocess
 import codecs
+import sys
 
 try:
     import configparser
@@ -122,10 +123,10 @@ class PictureChooserButton (Gtk.Button):
         widget = args[-1]
 
         window = widget.get_window()
-        screen = window.get_screen()
-        monitor = screen.get_monitor_at_window(window)
+        display = Gdk.Display.get_default()
+        monitor = display.get_monitor_at_window(window)
 
-        warea = screen.get_monitor_workarea(monitor)
+        warea = monitor.get_workarea()
         wrect = widget.get_allocation()
         mrect = menu.get_allocation()
 
@@ -207,8 +208,8 @@ class SettingsPage(Gtk.Box):
         Gtk.Box.__init__(self)
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_spacing(15)
-        self.set_margin_left(80)
-        self.set_margin_right(80)
+        self.set_margin_start(80)
+        self.set_margin_end(80)
         self.set_margin_top(15)
         self.set_margin_bottom(15)
 
@@ -226,8 +227,7 @@ class SettingsBox(Gtk.Frame):
         self.set_shadow_type(Gtk.ShadowType.IN)
         frame_style = self.get_style_context()
         frame_style.add_class("view")
-        self.size_group = Gtk.SizeGroup()
-        self.size_group.set_mode(Gtk.SizeGroupMode.VERTICAL)
+        self.size_group = Gtk.SizeGroup.new(Gtk.SizeGroupMode.VERTICAL)
 
         self.box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.add(self.box)
@@ -260,8 +260,8 @@ class SettingsRow(Gtk.ListBoxRow):
 
         hbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         hbox.set_border_width(5)
-        hbox.set_margin_left(20)
-        hbox.set_margin_right(20)
+        hbox.set_margin_start(20)
+        hbox.set_margin_end(20)
         self.add(hbox)
 
         grid = Gtk.Grid()
@@ -290,11 +290,8 @@ class MintLocale:
     def __init__(self):
 
         # Determine path to system locale-config
-        self.locale_path=''
-
-        if os.path.exists('/etc/default/locale'):
-            self.locale_path='/etc/default/locale'
-        else:
+        self.locale_path='/etc/default/locale'
+        if os.path.exists('/etc/locale.conf'):
             self.locale_path='/etc/locale.conf'
 
         # Prepare the APT cache
@@ -430,7 +427,6 @@ class MintLocale:
 
         self.accountService = AccountsService.UserManager.get_default().get_user(current_user)
         self.accountService.connect('notify::is-loaded', self.accountservice_ready)
-        self.accountService.connect('changed::', self.accountservice_changed)
 
         groups = grp.getgrall()
         for group in groups:
@@ -575,9 +571,6 @@ class MintLocale:
     def accountservice_ready(self, user, param):
         self.window.show()
 
-    def accountservice_changed(self, user):
-        print("AccountsService language is: '%s'" % user.get_language())
-
     def build_lang_list(self):
 
         self.locale_button.clear_menu()
@@ -608,23 +601,18 @@ class MintLocale:
         cur_index = -1  # find the locale :P
         locales = subprocess.check_output("localedef --list-archive", shell=True)
         locales = locales.decode('utf-8')
-
-        all_locales_are_utf8 = True
-        for line in locales.split("\n"):
-            line = line.replace("utf8", "UTF-8")
-            charmap = None
-            if len(line.split(".")) > 1:
-                charmap = line.split(".")[1].strip()
-                if charmap != "UTF-8":
-                    all_locales_are_utf8 = False
-                    break
-            else:
-                all_locales_are_utf8 = False
-                break
+        if len(locales) == 0:
+            print("Locale archive not found. Regenerate it with 'sudo locale-gen'.")
+            sys.exit(1)
 
         built_locales = {}
         for line in locales.rstrip().split("\n"):
             line = line.replace("utf8", "UTF-8")
+
+            # Only allow UTF-8 locales
+            if "UTF-8" not in line:
+                continue
+
             cur_index += 1
             locale_code = line.split(".")[0].strip()
             charmap = None
@@ -662,7 +650,7 @@ class MintLocale:
 
             flag_path = self.set_minority_language_flag_path(locale_code, flag_path)
 
-            if charmap is not None and not all_locales_are_utf8:
+            if charmap is not None and charmap != "UTF-8":
                 language_label = u"%s  <small><span foreground='#3c3c3c'>%s</span></small>" % (language_label, charmap)
 
             if os.path.exists(flag_path):
